lpschedule-generator
====================

Python package that enables the FSF_ to write the LibrePlanet_
schedule in Markdown_.

See "Installation_" to get started.

.. _Installation: https://pythonhosted.org/lpschedule-generator/install
.. _FSF: https://fsf.org
.. _LibrePlanet: https://libreplanet.org/conference
.. _Markdown: https://daringfireball.net/projects/markdown

canonical repo
--------------

::

   $ git clone https://notabug.org/rsd/lpschedule-generator.git


license
-------

lpschedule-generator is licensed under the `GNU Generaly Public
license version 3 or later`__.

.. _gplv3: https://www.gnu.org/licenses/gpl-3.0-standalone.html
__ gplv3_
